import { InstancesStore } from '@angular-three/core';
import { Directive, SkipSelf, Input, NgModule } from '@angular/core';
import { BoxBufferGeometry, CircleBufferGeometry, ConeBufferGeometry, CylinderBufferGeometry, DodecahedronBufferGeometry, ExtrudeBufferGeometry, IcosahedronGeometry, LatheBufferGeometry, OctahedronBufferGeometry, ParametricBufferGeometry, PlaneBufferGeometry, PolyhedronBufferGeometry, RingBufferGeometry, ShapeBufferGeometry, SphereBufferGeometry, TextBufferGeometry, TetrahedronBufferGeometry } from 'three';
import { CommonModule } from '@angular/common';

class ThreeBufferGeometry {
    constructor(instancesStore) {
        this.instancesStore = instancesStore;
        this._extraArgs = [];
    }
    set extraArgs(v) {
        this._extraArgs = v;
    }
    ngOnInit() {
        this._bufferGeometry = new this.geometryType(...this._extraArgs);
        this.instancesStore.saveBufferGeometry({
            id: this.ngtId,
            bufferGeometry: this._bufferGeometry,
        });
    }
    get bufferGeometry() {
        return this._bufferGeometry;
    }
    ngOnDestroy() {
        if (this.bufferGeometry) {
            this.instancesStore.removeBufferGeometry(this.ngtId || this.bufferGeometry.uuid);
        }
    }
}
ThreeBufferGeometry.decorators = [
    { type: Directive }
];
ThreeBufferGeometry.ctorParameters = () => [
    { type: InstancesStore, decorators: [{ type: SkipSelf }] }
];
ThreeBufferGeometry.propDecorators = {
    ngtId: [{ type: Input }]
};

class BoxBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = BoxBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
BoxBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-boxBufferGeometry',
                exportAs: 'ngtBoxBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: BoxBufferGeometryDirective,
                    },
                ],
            },] }
];
BoxBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class ThreeBoxBufferGeometryModule {
}
ThreeBoxBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [BoxBufferGeometryDirective],
                imports: [CommonModule],
                exports: [BoxBufferGeometryDirective],
            },] }
];

class CircleBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = CircleBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CircleBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-circleBufferGeometry',
                exportAs: 'ngtCircleBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: CircleBufferGeometryDirective,
                    },
                ],
            },] }
];
CircleBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class ThreeCircleBufferGeometryModule {
}
ThreeCircleBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CircleBufferGeometryDirective],
                imports: [CommonModule],
                exports: [CircleBufferGeometryDirective],
            },] }
];

class ConeBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = ConeBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
ConeBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-coneBufferGeometry',
                exportAs: 'ngtConeBufferGeometry',
                providers: [
                    { provide: ThreeBufferGeometry, useExisting: ConeBufferGeometryDirective },
                ],
            },] }
];
ConeBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class ConeBufferGeometryModule {
}
ConeBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ConeBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    ConeBufferGeometryDirective
                ]
            },] }
];

class CylinderBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = CylinderBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CylinderBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-cylinderBufferGeometry',
                exportAs: 'ngtCylinderBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: CylinderBufferGeometryDirective,
                    },
                ],
            },] }
];
CylinderBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class ThreeCylinderBufferGeometryModule {
}
ThreeCylinderBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CylinderBufferGeometryDirective],
                imports: [CommonModule],
                exports: [CylinderBufferGeometryDirective],
            },] }
];

class DodecahedronBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = DodecahedronBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
DodecahedronBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-dodecahedronBufferGeometry',
                exportAs: 'ngtDodecahedronBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: DodecahedronBufferGeometryDirective,
                    },
                ],
            },] }
];
DodecahedronBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class DodecahedronBufferGeometryModule {
}
DodecahedronBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    DodecahedronBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    DodecahedronBufferGeometryDirective
                ]
            },] }
];

class ExtrudeBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = ExtrudeBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
ExtrudeBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-extrudeBufferGeometry',
                exportAs: 'ngtExtrudeBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: ExtrudeBufferGeometryDirective,
                    },
                ],
            },] }
];
ExtrudeBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class ExtrudeBufferGeometryModule {
}
ExtrudeBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ExtrudeBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    ExtrudeBufferGeometryDirective
                ]
            },] }
];

class IcosahedronGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = IcosahedronGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
IcosahedronGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-icosahedronGeometry',
                exportAs: 'ngtIcosahedronGeometry',
                providers: [
                    { provide: ThreeBufferGeometry, useExisting: IcosahedronGeometryDirective },
                ],
            },] }
];
IcosahedronGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class ThreeIcosahedronGeometryModule {
}
ThreeIcosahedronGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [IcosahedronGeometryDirective],
                imports: [CommonModule],
                exports: [IcosahedronGeometryDirective],
            },] }
];

class LatheBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = LatheBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
LatheBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-latheBufferGeometry',
                exportAs: 'ngtLatheBufferGeometry',
                providers: [
                    { provide: ThreeBufferGeometry, useExisting: LatheBufferGeometryDirective },
                ],
            },] }
];
LatheBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class LatheBufferGeometryModule {
}
LatheBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    LatheBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    LatheBufferGeometryDirective
                ]
            },] }
];

class OctahedronBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = OctahedronBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
OctahedronBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-octahedronBufferGeometry',
                exportAs: 'ngtOctahedronBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: OctahedronBufferGeometryDirective,
                    },
                ],
            },] }
];
OctahedronBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class OctahedronBufferGeometryModule {
}
OctahedronBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    OctahedronBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    OctahedronBufferGeometryDirective
                ]
            },] }
];

class ParametricBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = ParametricBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
ParametricBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-parametricBufferGeometry',
                exportAs: 'ngtParametricBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: ParametricBufferGeometryDirective,
                    },
                ],
            },] }
];
ParametricBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class ParametricBufferGeometryModule {
}
ParametricBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ParametricBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    ParametricBufferGeometryDirective
                ]
            },] }
];

class PlaneBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = PlaneBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
PlaneBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-planeBufferGeometry',
                exportAs: 'ngtPlaneBufferGeometry',
                providers: [
                    { provide: ThreeBufferGeometry, useExisting: PlaneBufferGeometryDirective },
                ],
            },] }
];
PlaneBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class PlaneBufferGeometryModule {
}
PlaneBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    PlaneBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    PlaneBufferGeometryDirective
                ]
            },] }
];

class PolyhedronBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = PolyhedronBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
PolyhedronBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-polyhedronBufferGeometry',
                exportAs: 'ngtPolyhedronBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: PolyhedronBufferGeometryDirective,
                    },
                ],
            },] }
];
PolyhedronBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class PolyhedronBufferGeometryModule {
}
PolyhedronBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    PolyhedronBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    PolyhedronBufferGeometryDirective
                ]
            },] }
];

class RingBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = RingBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
RingBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-ringBufferGeometry',
                exportAs: 'ngtRingBufferGeometry',
                providers: [
                    { provide: ThreeBufferGeometry, useExisting: RingBufferGeometryDirective },
                ],
            },] }
];
RingBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class RingBufferGeometryModule {
}
RingBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    RingBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    RingBufferGeometryDirective
                ]
            },] }
];

class ShapeBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = ShapeBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
ShapeBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-shapeBufferGeometry',
                exportAs: 'ngtShapeBufferGeometry',
                providers: [
                    { provide: ThreeBufferGeometry, useExisting: ShapeBufferGeometryDirective },
                ],
            },] }
];
ShapeBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class ShapeBufferGeometryModule {
}
ShapeBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ShapeBufferGeometryDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    ShapeBufferGeometryDirective
                ]
            },] }
];

class SphereBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = SphereBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
SphereBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-sphereBufferGeometry',
                exportAs: 'ngtSphereBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: SphereBufferGeometryDirective,
                    },
                ],
            },] }
];
SphereBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class SphereBufferGeometryModule {
}
SphereBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SphereBufferGeometryDirective],
                imports: [CommonModule],
                exports: [SphereBufferGeometryDirective],
            },] }
];

class TextBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = TextBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
TextBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-textBufferGeometry',
                exportAs: 'ngtTextBufferGeometry',
                providers: [
                    { provide: ThreeBufferGeometry, useExisting: TextBufferGeometryDirective },
                ],
            },] }
];
TextBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class ThreeTextBufferGeometryModule {
}
ThreeTextBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TextBufferGeometryDirective],
                imports: [CommonModule],
                exports: [TextBufferGeometryDirective],
            },] }
];

class TetrahedronBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = TetrahedronBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
TetrahedronBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-tetrahedronBufferGeometry',
                exportAs: 'ngtTetrahedronBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: TetrahedronBufferGeometryDirective,
                    },
                ],
            },] }
];
TetrahedronBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

class TetrahedronBufferGeometryModule {
}
TetrahedronBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TetrahedronBufferGeometryDirective],
                imports: [CommonModule],
                exports: [TetrahedronBufferGeometryDirective],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { BoxBufferGeometryDirective, CircleBufferGeometryDirective, ConeBufferGeometryDirective, ConeBufferGeometryModule, CylinderBufferGeometryDirective, DodecahedronBufferGeometryDirective, DodecahedronBufferGeometryModule, ExtrudeBufferGeometryDirective, ExtrudeBufferGeometryModule, IcosahedronGeometryDirective, LatheBufferGeometryDirective, LatheBufferGeometryModule, OctahedronBufferGeometryDirective, OctahedronBufferGeometryModule, ParametricBufferGeometryDirective, ParametricBufferGeometryModule, PlaneBufferGeometryDirective, PlaneBufferGeometryModule, PolyhedronBufferGeometryDirective, PolyhedronBufferGeometryModule, RingBufferGeometryDirective, RingBufferGeometryModule, ShapeBufferGeometryDirective, ShapeBufferGeometryModule, SphereBufferGeometryDirective, SphereBufferGeometryModule, TetrahedronBufferGeometryDirective, TetrahedronBufferGeometryModule, TextBufferGeometryDirective, ThreeBoxBufferGeometryModule, ThreeBufferGeometry, ThreeCircleBufferGeometryModule, ThreeCylinderBufferGeometryModule, ThreeIcosahedronGeometryModule, ThreeTextBufferGeometryModule };
//# sourceMappingURL=angular-three-core-geometries.js.map
